==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/General/notifier/translations/notifier_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ru">
<defaultcodec></defaultcodec>
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Модуль уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="49"/>
        <source>About Notifier Plugin</source>
        <translation>О модуле уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Модуль уведомлений для Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Notifier Plugin Settings</source>
        <translation>Настройки модуля уведомлений</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Psi Notification</source>
        <translation>Уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="25"/>
        <source>Enable Psi notification</source>
        <translation>Включить уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Сообщение на рабочем столе</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Enable desktop notification</source>
        <translation>Показывать сообщение на рабочем столе</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Message delay, ms:</source>
        <translation>Задержка сообщения, мс:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="74"/>
        <source>Position</source>
        <translation>Позциция</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="255"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/notifier/translations/notifier_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Модуль уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>О модуле уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Модуль уведомлений для Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="115"/>
        <source>Volume:</source>
        <translation>Громкость:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Notifier Plugin Settings</source>
        <translation>Настройки модуля уведомлений</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Psi Notification</source>
        <translation>Уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="25"/>
        <source>Enable Psi notification</source>
        <translation>Включить уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Сообщение на рабочем столе</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Song change notification</source>
        <translation>Уведомление о смене песни</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Volume change notification</source>
        <translation>Уведомление о смене громкости</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Delay, ms:</source>
        <translation>Задержка, мс:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Transparency</source>
        <translation>Прозрачность</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="104"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
